==> haskell-wai-logger-2.2.4.1-4-armv7h.pkg.tar.xz: usr/share/haskell/haskell-wai-logger/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-logger
version: 2.2.4.1
id: wai-logger-2.2.4.1-f24597f93ba49a0bbd4e6ed0edc7bef2
key: wailo_41qEeyfO6h02gfuFm3hxTa
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: A logging system for WAI
description:
    A logging system for WAI
category: Web, Yesod
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.Wai.Logger
hidden-modules: Network.Wai.Logger.Apache Network.Wai.Logger.Date
                Network.Wai.Logger.IP Network.Wai.Logger.IORef
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/wai-logger-2.2.4.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/wai-logger-2.2.4.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/wai-logger-2.2.4.1
hs-libraries: HSwai-logger-2.2.4.1-41qEeyfO6h02gfuFm3hxTa
depends:
    auto-update-0.1.3-4edf36ce78b71bfaad1ce3737442c65f
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    byteorder-1.0.4-d0724ebba5f7969f1b97a3570748951d
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    case-insensitive-1.2.0.5-6669cd7a393ccedc4f66c0a01b6f0e2f
    easy-file-0.2.1-9b22ae8f4cbee2da82c99a0d82e5050c
    fast-logger-2.4.1-72875ca91290e61690089a3e7f5d8466
    http-types-0.9-d392878af9c5e1b1993961dc71a9e177
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
    unix-time-0.3.6-139be0d28d6f361941053e7ff9473819
    wai-3.2.0-61d8ab991e10dd6c5057d0dabf632d2a
haddock-interfaces: /usr/share/doc/haskell-wai-logger/html/wai-logger.haddock
haddock-html: /usr/share/doc/haskell-wai-logger/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-logger-2.2.4.1-6-armv7h.pkg.tar.xz: usr/share/haskell/haskell-wai-logger/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-logger
version: 2.2.4.1
id: wai-logger-2.2.4.1-9478a6051df96b8d5b3214f7fcca2185
key: wailo_1iM7IWzIYxc5wCErcOUTpR
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: A logging system for WAI
description:
    A logging system for WAI
category: Web, Yesod
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.Wai.Logger
hidden-modules: Network.Wai.Logger.Apache Network.Wai.Logger.Date
                Network.Wai.Logger.IP Network.Wai.Logger.IORef
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/wai-logger-2.2.4.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/wai-logger-2.2.4.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/wai-logger-2.2.4.1
hs-libraries: HSwai-logger-2.2.4.1-1iM7IWzIYxc5wCErcOUTpR
depends:
    auto-update-0.1.3-4edf36ce78b71bfaad1ce3737442c65f
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
    byteorder-1.0.4-d0724ebba5f7969f1b97a3570748951d
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    case-insensitive-1.2.0.6-c6baeb35be7a5ef7e8151f5e00d87f59
    easy-file-0.2.1-9b22ae8f4cbee2da82c99a0d82e5050c
    fast-logger-2.4.1-5b4c33804a079c795a3744fd9f8cdcd3
    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
    unix-time-0.3.6-139be0d28d6f361941053e7ff9473819
    wai-3.2.0-7ea0a12f4ecd69f2ebdeef193a494430
haddock-interfaces: /usr/share/doc/haskell-wai-logger/html/wai-logger.haddock
haddock-html: /usr/share/doc/haskell-wai-logger/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
